*	SPSS syntax files for calculating and appending wealth index variables to SPSS MICS data files
		Part 1	Get data, create macros
		Part 2	Prepare variables for inclusion in wealth index calculations
		Part 3	Run PCA for urban areas only
		Part 4	Run PCA for rural areas only
		Part 5	Run a common PCA
		Part 6	Run regressions
		Part 7	Calculate combined wealth scores, check results
		Part 8	Create quintiles, review and compare results
		Part 9	Append wealth index variables to MICS SPSS data files.

*	wealth0.sps (this syntax) is the main program which runs the other syntax - this should be run in its entirety after 
		all of the syntax are considered final. Note that wealth9.sps is intended to append the 
		wealth index variables onto all data sets, and should be run only after all other programs are final, and wealth index
		variables are to be appended to the data sets for good.

*	These programs are based on the standard MICS questionnaires and example data sets,  
		and need to be customized for each country survey, 
		in accordance with the customized country MICS questionnaires.

*	Final versions of these programs should be run after structural checks are completed and household weights are finalized
		If any changes are made to the data files or the sample weights, the program needs to be re-run, wealth index variables 
		need to be re-calculated and re-appended to the data sets.

*	The household (hh.sav) and household members (hl.sav) data files are needed to calculate the wealth index variables
	The six wealth index variables created are:
		[1] wscoreu (wealth scores for urban areas), 
		[2] windex5u (wealth index quintiles for urban areas),
		[3] wscorer (wealth scores for rural areas), 
		[4] windex5r (wealth index quintiles for rural areas),
		[5] wscore (national wealth scores, combined), 
		[6] windex5 (national wealth index quintiles, combined).

*	Several runs of the programs will be needed before the wealth index variables are finalized and merged to the data sets for good
	Run and finalize each syntax from 1 to 8 - do not proceed to the next syntax until the previous one is considered final
	Once all syntax from 1 to 8 are final, wealth9 should be customized and run to append wealth index variables to all the data sets
	Ensure that the data sets do not already have the wealth index variables
		If they do, then the programs will fail to replace them with the new values of the variables.

*	For surveys where "urban" and "rural" do not exist (such as a survey of population in camps, and ethnic group), the initial (common) 
		wealth scores and wealth index should be created and appended to the data sets 
		- significant customization of the syntax will be needed.

*	For details of the wealth index, see 
		http://www.measuredhs.com/publications/publication-CR6-Comparative-Reports.cfm
		http://www.measuredhs.com/publications/publication-WP60-Working-Papers.cfm.


*	Describe where the hh.sav and hl.sav data files are stored.
cd "C:\MICS5\SPSS".

*	Replace below "Country, Year" with the name of the country/survey, and the year of fieldwork - this will appear in all 
	oitputs of these programs.
define surveyname ()
	"Country, Year"
!enddefine.


* =================================================================
*	Commands below should not be run before customizing/finalizing each of the 
		indicated syntax.

* Part 1	Get data, create macros. 
	insert file = "wealth1.sps".
* Part 2	Prepare variables for inclusion in wealth index calculations.
	insert file = "wealth2.sps".
* Part 3	Run an initial common PCA.
	insert file = "wealth3.sps".
* Part 4	Run PCA for urban areas only.
	insert file = "wealth4.sps".
* Part 5	Run PCA for rural areas only.
	insert file = "wealth5.sps".
* Part 6	Run regressions.
	insert file = "wealth6.sps".
* Part 7	Calculate combined wealth scores, check results.
	insert file = "wealth7.sps".
* Part 8	Create quintiles, review and compare results.
	insert file = "wealth8.sps".
* Part 9	Append wealth index variables to MICS SPSS data files.
* As a precaution, the next line is commented out. This should be run only after making sure that all the syntaxes above are final.
*	insert file = "wealth9.sps".



