
* =================================================================
GET DATA, CREATE MACROS
==================================================================

new file.

*	Get the household members data file and create a household file with households that have live-in servants and parents living abroad
	If these questions/codes do not exist in your survey, comment out or delete the lines below, and go directly to get the hh.sav data file -
	You will not need the hl.sav data file, and will need to delete all references to the "abroad" and "servant" variables from the syntax files
	If one of these questions/codes is included, then customize accordingly - delete references to the variable that cannot be constructed.
get file = "hl.sav".
recode hl3 (14=1) (else=0) into servant.
compute abroad = 0.
if (hl12a = 3 or hl14a = 3) abroad = 1.
execute.

sort cases hh1 hh2.
aggregate
  	/outfile="temp.sav"
	/break=hh1 hh2
	/servant	"At least one live-in servant in the household" = max(servant) 
	/abroad	"At least one household member living abroad" = max(abroad).


*	Get the household data file and select only households with completed interviews.
get file = "hh.sav".
sort cases hh1 hh2.
dataset name assets.
select if (hh9=1).

match files
  /file = *
  /table = 'temp.sav'
  /by HH1 HH2 .


*	Compute national, urban and rural variables coded (1/0) for filters and tabulations that will be run later.
compute national=1.
compute urban=(HH6 = 1).
compute rural=(HH6 = 2).
recode urban rural (0=sysmis).
variable labels national	'National'.
variable labels urban		'Urban'.
variable labels rural		'Rural'.
value labels national 	1 'National'.
value labels urban 	1 'Urban'.
value labels rural 	1 'Rural'.
formats national urban rural (f1.0).
execute.


* =================================================================
* 	Define macros
 	Caution on the use of macros: 	
 		Do not use an asterisk in front of a macro name to try to comment it out  	
			as it will run anyway because of the way macros expand
           		Delete the whole line instead or change the spelling of the macro in the comment
		One way to do this is to replace the first letter of the macro name with a star (in which case, the line will become a comment)
		For example, if kerosene fuel use does not exist in your data or is only one case, you should change the line to
				*ichotomize hc6 (05) (98 thru hi) hc6@05	"Kerosene fuel"
		Do not use the names of macros in comments - they will also be expanded too, and likely will fail
		In the comment lines below, where examples are given, the actual macro names are not used, 
			but indicated with "macroname".


* 	Macro to generate percentage distributions of several variables with one run, for the total sample, and by urban and rural areas
	Example: "macroname hc9a hc9b hc9c @." produces percent distributions of hc9a hc9b and hc9c, for the total sample, and
		by urban and rural areas
	Include as many variables as needed.
define varpdist (!pos !charend ('@'))
!DO !i !IN (!1)
ctables 	/table !i [c] [colpct,'Percentage',f4.1,count,'Count',f5.0]
	by national [c] + urban [c] + rural [c]
	/titles title=surveyname
		"Percentage distributions and numbers of cases for the national sample, urban and rural areas"
	/categories variables=!i total=yes.
!DOEND
!ENDDEFINE.


* 	Macro to generate means, sums and valid counts for several variables with one run, for the total sample, and by urban and rural areas
	Example: "macroname ((var1 + var2 + var3))" produces summary statistics for variables var1, var2 and var3, for the total sample, and
		by urban and rural areas
	Include as many variables as needed.
define varmeans (!pos !enclose('(',')'))
ctables 	/table !1 [s] [validn 'Count' f5.0 sum 'Sum' f9.0 mean 'Mean' f5.4 missing 'Missing' f5.0] 
	by national [c] + urban [c] + rural [c]
	/titles title=Surveyname
		"Numbers of cases, sums, means and missing cases for the national sample, urban and rural areas"
!enddefine.


* 	Macro to generate means for several variables with one run, for the combined wealth quintiles
	Example: "macroname ((var1 + var2 + var3))" produces means for variables var1, var2 and var3, for the total sample, and
		by urban and rural areas
	Include as many variables as needed.
define cwealthmeans (!pos !enclose('(',')'))
ctables 	/table !1 [s] [mean '' f5.4] 
	by niniscor [c] + ncomscor [c]
	/categories variables = ncomscor total = yes
	/titles title=Surveyname
		"Average values of component indicators in initial (common) and combined wealth index quintiles"
!enddefine.


*	Macro to recode variables as dichotomous variables
 	Creates binary variables (1/0) and gives labels
	Example: macroname hc9a (1) (9) hc9a@r "Watch"
	Creates new variable hc9a@r from hc9a - (1) is recoded as (1), (9) is declared as missing, and all other cases are set to (0)
	Variable label for new variable becomes "Watch".
define dichotomize( !pos !tokens(1) / !pos !enclose('(',')') / !pos !enclose('(',')') / !pos !tokens(1) / !pos !tokens(1) )
recode !1 (!2 = 1) (!3 = 9) (else = 0) into !4.
variable labels !4 !5.
value labels !4 1 !5 0 "No" 9 "Missing".
missing values !4 (9).
formats !4 (f1.0).
!enddefine.


*	Macro for creating continuous variables based on condition and for giving labels
 	Example: macroname hc12n (0 thru 95) (98 thru hi) agland_ha "Household owns agricultural land: hectares".
define continuize( !pos !tokens(1) / !pos !enclose('(',')') / !pos !enclose('(',')') / !pos !tokens(1) / !pos !tokens(1) )
recode !1 (!2 = copy) (!3 = 999) (else = 0) into !4.
variable labels !4 !5.
value labels !4 999 "Missing".
missing values !4 (999).
formats !4 (f3.0).
!enddefine.


*	Macro to separate shared toilets from non-shared toilets
	If a toilet is shared, then these commands create two variables from the original variable, as shared and non-shared
	Example: macroname ws8@13 ws8@13s "Flush to pit latrine toilet - shared"
	ws8@13 is originally all households using flush to pit latrine toilet
	After the macro is run, 	ws8@13 becomes households using flush to pit latrine toilet and not sharing their toilet, 
			ws8@13s includes households using flush to pit latrine toilet and sharing their toilet 
				with other households (or as a public toilet)
	Continuing this example, ws8@13s does not need to be used in the PCA - only the ws8@13 etc variables are used,
			together with variables created on sharing in wealth2.sps (latshare, or lathh1 and lathh2 - see comments in wealth2.sps).
define sharedfac( !pos !tokens(1) / !pos !tokens(1) / !pos !tokens(1) ).
compute !2 = 0.
do if (latshare=1).
+ compute !2 = !1.
+ compute !1 = 0.
end if.
variable labels !2 !3.
value labels !2 1 !3 0 "No" 9 "Missing".
missing values !2 (9).
formats !2 (f1.0).
!enddefine.
