* =================================================================
PREPARE VARIABLES FOR INCLUSION IN WEALTH INDEX CALCULATIONS
==================================================================

* 	This syntax is to:
	(1) Generate percentage distributions and counts of all variables considered for the wealth index - getting to know your data
	(2) Transform, recode and finalize variables for inclusion in wealth index
	(3) Check means and counts of all recoded (binary) variables before moving on to the wealth index calculations.


* =================================================================
*	First look at the data
	Generate valid counts and percentage distributions of variables that are likely to be used in wealth index construction, 
		for the national total, urban and rural areas
	These are variables which are typically used in wealth index calculations or can inform you on the nature of data
	If any of the variables below are not included in the country questionnaire, they need to be taken out
	If there are any other variables added to the questionnaires suitable for use in welth index calculations, 
		they need to be added to the list.
varpdist 	hh11 hc2 hc3 hc4 hc5 hc6
	hc8a hc8b hc8c hc8d hc8e hc8f 
	hc9a hc9b hc9c hc9d hc9e hc9f hc9g hc9h
	hc10
	hc11 hc12 hc13 hc14a hc14b hc14c hc14d hc14e hc14f hc14g
	hc15
	ws1 ws3 ws4 
	ws8 ws9 ws10 ws11
	hw1 hw2 hw3a hw4
	servant abroad @.

* 	Create the SPSS output.
output save outfile = "wealth2 syntax output.spv".

* 	Pause here and study the results of the tables showing distrbutions of the variables
	(1) For any variables that you may not have in your survey, take them out below
	(2) For any wealth-related variables added onto your survey (for example, country-specific assets), add them above and below
	(3) Any variables with no cases (for the total sample) will need to be commented out below



* =================================================================
* 	Construct variables to be included in the wealth index calculations.

*	Persons per sleeping room
	Normally, values of hc2 should range from 1 to x - program will stop if hc2=0 and this will need to be corrected in the data set
		or declared missing below.
do if (hc2 < 98).
compute persroom = hh11 / hc2.
else.
compute persroom = 99.
end if.
missing values persroom (99).
variable labels persroom "Persons per sleeping room".
execute.


*	Type of floor (hc3)
	Dichotomized variables for each response category of floor material
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize hc3 (11) (98 thru hi) hc3@11	"Earth/sand floor".
dichotomize hc3 (12) (98 thru hi) hc3@12	"Dung floor".
dichotomize hc3 (21) (98 thru hi) hc3@21	"Wood planks floor".
dichotomize hc3 (22) (98 thru hi) hc3@22	"Palm/bamboo floor".
Dichotomize hc3 (31) (98 thru hi) hc3@31	"Parquet/polished wood floor".
dichotomize hc3 (32) (98 thru hi) hc3@32	"Vinyl/asphalt strip floor".
dichotomize hc3 (33) (98 thru hi) hc3@33	"Ceramic tiles floor".
dichotomize hc3 (34) (98 thru hi) hc3@34	"Cement floor".
dichotomize hc3 (35) (98 thru hi) hc3@35	"Carpet floor".


*	Type of roof (hc4)
	Dichotomized variables for each response category of roof material
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize hc4 (11) (98 thru hi) hc4@11	"No roof".
dichotomize hc4 (12) (98 thru hi) hc4@12	"Thatch/palm leaf roof".
dichotomize hc4 (13) (98 thru hi) hc4@13	"Sod roof".
dichotomize hc4 (21) (98 thru hi) hc4@21	"Rustic mat roof".
dichotomize hc4 (22) (98 thru hi) hc4@22	"Palm/bamboo roof".
dichotomize hc4 (23) (98 thru hi) hc4@23	"Wood planks roof".
dichotomize hc4 (24) (98 thru hi) hc4@24	"Cardboard roof".
dichotomize hc4 (31) (98 thru hi) hc4@31	"Metal/tin roof".
dichotomize hc4 (32) (98 thru hi) hc4@32	"Wood roof".
dichotomize hc4 (33) (98 thru hi) hc4@33	"Calamine/cement fibre roof".
dichotomize hc4 (34) (98 thru hi) hc4@34	"Ceramic tiles roof".
dichotomize hc4 (35) (98 thru hi) hc4@35	"Cement roof".
dichotomize hc4 (36) (98 thru hi) hc4@36	"Roofing shingles roof".


*	Type of wall (hc5)
	Dichotomized variables for each response category of wall material
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize hc5 (11) (98 thru hi) hc5@11	"No walls".
dichotomize hc5 (12) (98 thru hi) hc5@12	"Cane/palm/trunks walls".
dichotomize hc5 (13) (98 thru hi) hc5@13	"Dirt walls".
dichotomize hc5 (21) (98 thru hi) hc5@21	"Bamboo with mud wall".
dichotomize hc5 (22) (98 thru hi) hc5@22	"Stone with mud walls".
dichotomize hc5 (23) (98 thru hi) hc5@23	"Uncovered adobe walls".
dichotomize hc5 (24) (98 thru hi) hc5@24	"Plywood walls".
dichotomize hc5 (25) (98 thru hi) hc5@25	"Cardboard walls".
dichotomize hc5 (26) (98 thru hi) hc5@26	"Reused wood walls".
dichotomize hc5 (31) (98 thru hi) hc5@31	"Cement walls".
dichotomize hc5 (32) (98 thru hi) hc5@32	"Stone with lime/cement walls".
dichotomize hc5 (33) (98 thru hi) hc5@33	"Brick walls".
dichotomize hc5 (34) (98 thru hi) hc5@34	"Cement blocks walls".
dichotomize hc5 (35) (98 thru hi) hc5@35	"Covered adobe walls".
dichotomize hc5 (36) (98 thru hi) hc5@36	"Wood planks/shingles walls".


*	Type of household fuel (hc6)
	Dichotomized variables for each response category of fuel for cooking
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize hc6 (01) (98 thru hi) hc6@01	"Electricity fuel".
dichotomize hc6 (02) (98 thru hi) hc6@02	"LPG fuel".
dichotomize hc6 (03) (98 thru hi) hc6@03	"Natural gas fuel".
dichotomize hc6 (04) (98 thru hi) hc6@04	"Biogas fuel".
dichotomize hc6 (05) (98 thru hi) hc6@05	"Kerosene fuel".
dichotomize hc6 (06) (98 thru hi) hc6@06	"Coal/lignite fuel".
dichotomize hc6 (07) (98 thru hi) hc6@07	"Charcoal fuel".
dichotomize hc6 (08) (98 thru hi) hc6@08	"Wood fuel".
dichotomize hc6 (09) (98 thru hi) hc6@09	"Straw/shrub/grass fuel".
dichotomize hc6 (10) (98 thru hi) hc6@10	"Animal dung fuel".
dichotomize hc6 (11) (98 thru hi) hc6@11	"Agrciultural crop residue fuel".
dichotomize hc6 (95) (98 thru hi) hc6@95	"No food cooked".


*	Household assets (items in hc8)
	Dichotomized variables for each household asset
	There should be as many variables as the items in hc8
	The variable label of hc8f should be changed, other items should be added below, if any.
dichotomize hc8a (1) (9) hc8a@1 	"Electricity".
dichotomize hc8b (1) (9) hc8b@1	"Radio".
dichotomize hc8c (1) (9) hc8c@1	"Television".
dichotomize hc8d (1) (9) hc8d@1	"Non-mobile telephone".
dichotomize hc8e (1) (9) hc8e@1	"Refrigetaror".
dichotomize hc8f (1) (9) hc8f@1	"Country specific item".


*	Household members assets (items in hc9)
	Dichotomized variables for each household asset
	There should be as many variables as the items in hc8
	The variable label of hc9h should be changed, other items should be added below, if any.
dichotomize hc9a (1) (9) hc9a@1	"Watch".
dichotomize hc9b (1) (9) hc9b@1	"Mobile telephone".
dichotomize hc9c (1) (9) hc9c@1	"Bicycle".
dichotomize hc9d (1) (9) hc9d@1	"Motorcycle/scooter".
dichotomize hc9e (1) (9) hc9e@1	"Animal drawn cart".
dichotomize hc9f (1) (9) hc9f@1	"Car/truck".
dichotomize hc9g (1) (9) hc9g@1	"Boat with motor".
dichotomize hc9h (1) (9) hc9h@1	"Country specific item".


*	Ownership of dwelling (hc10)
	Dichotomized variables for each response category
	There should be as many variables as the response codes.
dichotomize hc10 (1) (9) hc10@1 	"Owns dwelling".
dichotomize hc10 (2) (9) hc10@2	"Rents dwelling".
dichotomize hc10 (6) (9) hc10@6	"Other dwelling arrangement".

*	Ownership of bank account (hc15).
*	This is recoded early on, to allow use in analyses below.
dichotomize hc15 (1) (9) hc15@1 	"Household owns bank account".


*	Ownership of agricultural land and livestock (hc11, hc12, hc13 and hc14a to hc14f)
	Information on agricultural land and specific livestock are collected as continuous variables
	The aim of recoding here is to generate grouped variables for each, and then dichotomize these groups into separate variables
	Since both agricultural land and livestock ownership are primarily rural attributes, groups need to be decided by taking the 
		rural distributions into account.
*	Groups can be decided in various ways:
		[1] Plot ogives of amount of land owned, or numbers of animals, to detect natural break points
		[2] Use "anchor" variables (those items that are thought be be desirable by all of the population
			such as electricity, television, refrigerator, which are almost always strongly associated with wealth)
			and obtain the proportions of households that have these items, by (groups of) households according to 
			land and livestock ownership
			For example, you may do the following:
			count items = hc8a@1 hc8c@1 hc8d@1 hc8e@1 hc9b@1 hc9f@1 hc15@1 (1)
			and study the average number of items by land and livestock ownership
			to decide grouping of land and livestock variables.
*	Groups below are for demonstration purposes only.


*	Land ownership
	You should aim to identify maximum 4 groups (those with no land included) - in some way, the grouping should refer to
		Households with no land
		Households that are small land owners (a few acres)
		Households that are large land owners, and 
		Households that fall between small and large land owners.

*	First, recode households that have less than one acre of land, into one acre - these are originally coded as hc12=0 in the data set.
recode hc12 (0=1) (996 thru hi=999) (else=copy) into hc12r.
if (hc11=2) hc12r=0.
missing values hc12r (999).

*	Note: In the event that only two groups, one with no land, and the other with some land can be identified,
		only one group with some land should be dichotomized here and entered to the PCA calculations.
dichotomize hc12r (0) (999) hc12r@0 		"No agricultural land".
dichotomize hc12r (1 thru 19) (999) hc12r@1		"Up to 20 acres of agricultural land".
dichotomize hc12r (20 thru 100) (999) hc12r@2		"20-100 acres of agricultural land".
dichotomize hc12r (101 thru 995) (999) hc12r@3	"More than 100 acres of agricultural land".


*	Ownership of livestock (hc13 and hc14a to hc14f)
	Same approaches as above
	Groups below are for demonstration purposes only.

*	First, recode households with no livestock into 0 for all variables.
recode hc14a hc14b hc14c hc14d hc14e hc14f (sysmis=0).
varpdist hc14a hc14b hc14c hc14d hc14e hc14f @.


*	Note: In the event that only two groups (for each type of animal), one with no animal of that type, 
		and the other with some animals of that type can be identified,
		only one group including households with more than one animal of that type 
		should be dichotomized here and entered to the PCA calculations.
dichotomize hc14a (0) (96 thru 99) 		hc14a@0	"No cattle, milk cows or bulls".
dichotomize hc14a (1 thru 4) (96 thru 99) 	hc14a@1	"1-4 cattle, milk cows or bulls".
dichotomize hc14a (5 thru 9) (96 thru 99) 	hc14a@2	"5-9 cattle, milk cows or bulls".
dichotomize hc14a (10 thru 95) (96 thru 99) 	hc14a@3	"10+ cattle, milk cows or bulls".

dichotomize hc14b (0) (96 thru 99) 		hc14b@0	"No horses, donkeys, mules".
dichotomize hc14b (1 thru 4) (96 thru 99) 	hc14b@1	"1-4 horses, donkeys, mules".
dichotomize hc14b (5 thru 9) (96 thru 99) 	hc14b@2	"5-9 horses, donkeys, mules".
dichotomize hc14b (10 thru 95) (96 thru 99) 	hc14b@3	"10+ horses, donkeys, mules".

dichotomize hc14c (0) (96 thru 99) 		hc14c@0	"No goats".
dichotomize hc14c (1 thru 4) (96 thru 99) 	hc14c@1	"1-4 goats".
dichotomize hc14c (5 thru 9) (96 thru 99) 	hc14c@2	"5-9 goats".
dichotomize hc14c (10 thru 95) (96 thru 99) 	hc14c@3	"10+ more goats".

dichotomize hc14d (0) (96 thru 99) 		hc14d@0	"No sheep".
dichotomize hc14d (1 thru 4) (96 thru 99) 	hc14d@1	"1-4 sheep".
dichotomize hc14d (5 thru 9) (96 thru 99) 	hc14d@2	"5-9 sheep".
dichotomize hc14d (10 thru 95) (96 thru 99) 	hc14d@3	"10+ more sheep".

dichotomize hc14e (0) (96 thru 99) 		hc14e@0	"No chickens".
dichotomize hc14e (1 thru 9) (96 thru 99) 	hc14e@1	"1-9 chickens".
dichotomize hc14e (10 thru 19) (96 thru 99) 	hc14e@2	"10-19 chickens".
dichotomize hc14e (20 thru 95) (96 thru 99) 	hc14e@3	"20+ chickens".

dichotomize hc14f (0) (96 thru 99) 		hc14f@0	"No pigs".
dichotomize hc14f (1 thru 4) (96 thru 99) 	hc14f@1	"1-4 pigs".
dichotomize hc14f (5 thru 9) (96 thru 99) 	hc14f@2	"5-9 pigs".
dichotomize hc14f (10 thru 95) (96 thru 99) 	hc14f@3	"10+ pigs".


*	Source of drinking water (ws1)
	Dichotomized variables for each response category of source of drinking water
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize ws1 (11) (98 thru hi) ws1@11 	"Water piped into dwelling".
dichotomize ws1 (12) (98 thru hi) ws1@12 	"Water piped into yard/plot".
dichotomize ws1 (13) (98 thru hi) ws1@13 	"Water piped to neighbor".
dichotomize ws1 (14) (98 thru hi) ws1@14 	"Public tap/standpipe for water".
dichotomize ws1 (21) (98 thru hi) ws1@21 	"Tubewell/borehole for water".
dichotomize ws1 (31) (98 thru hi) ws1@31 	"Protected well for water".
dichotomize ws1 (32) (98 thru hi) ws1@32	"Unprotected well for water".
dichotomize ws1 (41) (98 thru hi) ws1@41	"Protected spring for water".
dichotomize ws1 (42) (98 thru hi) ws1@42	"Unprotected spring for water".
dichotomize ws1 (51) (98 thru hi) ws1@51	"Rainwater for water".
dichotomize ws1 (61) (98 thru hi) ws1@61	"Tanker truck for water".
dichotomize ws1 (71) (98 thru hi) ws1@71	"Cart with small tank for water".
dichotomize ws1 (81) (98 thru hi) ws1@81	"Surface water".
dichotomize ws1 (91) (98 thru hi) ws1@91	"Bottled water".


* 	Location of water source (ws3)
	Dichotomized variables for each location category
	Set households with water in dwelling, according to responses in ws1 and ws2, to zero.
recode ws3 (sysmis=1) (1,2,3=copy) (else=9) into watloc.
if (watloc=3 and ws4 ge 30 and ws4 le 995) watloc=4.
dichotomize watloc (1) (9) watloc@1	"Water in own dwelling".
dichotomize watloc (2) (9) watloc@2	"Water in own yard or plot".
dichotomize watloc (3) (9) watloc@3	"Water less than 30 minutes away".
dichotomize watloc (4) (9) watloc@4	"Water more than 30 minutes away".


*	A series of variables on types of sanitation facilities and sharing of such facilities is created below
	Not all of these variables should be used in the PCA
	Decisions on which variables will be used need to be taken after distributions are examined.

*	Variables on sharing of sanitation facilities are created below
	In the wealth index calculations, either "latshare" (if the total proportion of shared facilities is low) will be used, or 
	both "lathh1" and "lathh2" (if there are large numbers of cases in these categories) will be used.
dichotomize ws9 (1) (9) latshare		"Shares toilet with other households or uses public toilets".
dichotomize ws11 (2 thru 9) (98, 99) lathh1	"Shares toilet with less than 10 households".
dichotomize ws11 (10) (98, 99) lathh2	"Shares toilet with 10+ households or uses public toilets".
if (ws10 = 2) lathh2 = 1.

*	Type of sanitation facility (ws8)
	Dichotomized variables for each response category of type of sanitation
	There should be as many variables as the response codes - exclude "Other" responses.
dichotomize ws8 (11) (98 thru hi) ws8@11	"Flush to piped sewer system toilet".
dichotomize ws8 (12) (98 thru hi) ws8@12	"Flush to septic system toilet".
dichotomize ws8 (13) (98 thru hi) ws8@13	"Flush to pit latrine toilet".
dichotomize ws8 (14) (98 thru hi) ws8@14	"Flush to somewhere else toilet".
dichotomize ws8 (15) (98 thru hi) ws8@15	"Flush to unknown place toilet".
dichotomize ws8 (21) (98 thru hi) ws8@21	"Vent improved pit latrine toilet".
dichotomize ws8 (22) (98 thru hi) ws8@22	"Pit latrine with slab toilet".
dichotomize ws8 (23) (98 thru hi) ws8@23	"Pit latrine without slab toilet".
dichotomize ws8 (31) (98 thru hi) ws8@31	"Composting toilet".
dichotomize ws8 (41) (98 thru hi) ws8@41	"Bucket toilet".
dichotomize ws8 (51) (98 thru hi) ws8@51	"Hanging toilet".
dichotomize ws8 (95) (98 thru hi) ws8@95	"Bush/field/no toilet".


* 	To check which sanitation facilities are shared
		run the table below.
ctables 	/table ws8 [c] 
	by (lathh1 + lathh2) [s] [sum '' f5.0] + national [s] [sum '' f5.0]
	/categories variables=ws8 total=yes.

* 	Create the SPSS output.
output save outfile = "wealth2 syntax output.spv".


*	Separate out shared toilets and non-shared (private) toilets.
sharedfac ws8@11 ws8@11s	"Flush to piped sewer system toilet - shared".
sharedfac ws8@12 ws8@12s	"Flush to septic system toilet - shared".
sharedfac ws8@13 ws8@13s	"Flush to pit latrine toilet - shared".	
sharedfac ws8@14 ws8@14s	"Flush to somewhere else toilet - shared".
sharedfac ws8@15 ws8@15s	"Flush to unknown place toilet - shared".	
sharedfac ws8@21 ws8@21s	"Vent improved pit latrine toilet - shared".
sharedfac ws8@22 ws8@22s	"Pit latrine with slab toilet - shared".
sharedfac ws8@23 ws8@23s	"Pit latrine without slab toilet - shared".
sharedfac ws8@31 ws8@31s	"Composting toilet - shared".
sharedfac ws8@41 ws8@41s	"Bucket toilet - shared".
sharedfac ws8@51 ws8@51s	"Hanging toilet - shared".	


* 	Availability of water at place for handwashing
	Note that missing cases in this variable are those households where the respondent refused to 
		show the place for handwashing, or an "other" response was coded
	Households where place of handwashing was not observed because the place is not in the dwelling (code 2 for hw1)
		are considered not to have water present at handwashing place in the dwelling
	If more than 10 percent of households have missing values, comment these lines out and do not include this variable.
dichotomize hw2 (1) (9) hw2@1		"Water present at handwashing place in the dwelling".
* To account for those cases where place for handwashing is not in the dwelling.
if (hw1=2) hw2@1=0.


* 	Availability of soap.
compute soap = 9.
if (hw3a = 1 or hw4= 1) soap = 1.
if (hw3a = 2 and hw4 = 2) soap = 0.
dichotomize soap (1) (9) soap@1 		"Has soap in household".


* =================================================================
* Run summary statistics for recoded variables, to decide whether or not to include them 
		and to see whether they have been constructed correctly.
varmeans 	((persroom)).
varmeans 	((hc3@11 + hc3@12 + hc3@21 + hc3@22 + hc3@31 + hc3@32 + hc3@33 + hc3@34 + hc3@35)).
varmeans 	((hc4@11 + hc4@12 + hc4@13 + hc4@21 + hc4@22 + hc4@23 + hc4@24 + hc4@31 + hc4@32 + 
		hc4@33 + hc4@34 + hc4@35 + hc4@36)).
varmeans 	((hc5@11 + hc5@12 + hc5@13 + hc5@21 + hc5@22 + hc5@23 + hc5@24 + hc5@25 + hc5@26 +
		hc5@31 + hc5@32 + hc5@33 + hc5@34 + hc5@35 + hc5@36)).
varmeans  	((hc6@01 + hc6@02 + hc6@03 + hc6@04 + hc6@05 + hc6@06 + hc6@07 + hc6@08 + hc6@09 + 
		hc6@10 + hc6@11 + hc6@95)).
varmeans  	((hc8a@1 + hc8b@1 + hc8c@1 + hc8d@1 + hc8e@1 + hc8f@1)).
varmeans  	((hc9a@1 + hc9b@1 + hc9c@1 + hc9d@1 + hc9e@1 + hc9f@1 + hc9g@1 + hc9h@1)).
varmeans 	((hc10@1 + hc10@2 + hc10@6)).
varmeans	((hc12r@0 + hc12r@1 + hc12r@2 + hc12r@3)).
varmeans 	((hc14a@0 + hc14a@1 + hc14a@2 + hc14a@3)).
varmeans  	((hc14b@0 + hc14b@1 + hc14b@2 + hc14b@3)).
varmeans  	((hc14c@0 + hc14c@1 + hc14c@2 + hc14c@3)). 
varmeans  	((hc14d@0 + hc14d@1 + hc14d@2 + hc14d@3)). 
varmeans  	((hc14e@0 + hc14e@1 + hc14e@2 + hc14e@3)). 
varmeans  	((hc14f@0 + hc14f@1 + hc14f@2 + hc14f@3)). 
varmeans	((hc15@1)).
varmeans  	((ws1@11 + ws1@12 + ws1@13 + ws1@14 + ws1@21 + ws1@31 + ws1@32 + 
		ws1@41 + ws1@42 + ws1@51 + ws1@61 + ws1@71 + ws1@81 + ws1@91)).
varmeans  	((watloc@1 + watloc@2 + watloc@3 + watloc@4)).
varmeans	((latshare + lathh1 + lathh2)).
varmeans  	((ws8@11 + ws8@12 + ws8@13 + ws8@14 + ws8@15 + ws8@21 + ws8@22 + ws8@23 + 
		ws8@31 + ws8@41 + ws8@51 + ws8@95)).
varmeans 	((hw2@1 + soap@1)).
varmeans	((servant + abroad)).

* 	Create the SPSS output.
output save outfile = "wealth2 syntax output.spv".

*	Close the output.
output close.