* =================================================================
RUN PCA FOR URBAN AREAS ONLY
==================================================================

use all.
filter by urban.
execute.


*	There are only three commands below, all of which will need to be run several times before concluding the urban index
	The first command groups all variables to be included in the PCA
	The second command deletes any existing urban factor score (urb1) in the data set
	The third command runs the PCA for the variables defined in the group
	All variables recoded in wealth2.sps are included below.
*	Follow these steps to customize:
	[1] 	Take out any variables that have less than 2 cases from the list below and list them here
		Variables excluded:
	[2]	Take out lathh1 and lathh2 (if the total proportion of shared facilities, latshare, is low), or latshare (if there are 
		significant proportions of households in lathh1 and lathh2). Indicate what you have taken out below
		Variable(s) excluded:
	[3]	Run the three commands below
	[4]	After studying the PCA results, take out from the list below any variables which seem to be correlated with the 
		model in a way contrary to what is theoretically expected - such as negative relationship of land ownership with the model,
		which indicates that the more land a household has, the poorer it is. List the variables excluded here
		Variables excluded:
	[5] 	Run the three commands below once more
	[6]	After studying the PCA results once again, take out from the list below any variables which seem to be not correlated 
		with the model (with zero coefficients). List the variables excluded here
		Variables excluded
	[7] 	Run the three commands below once more
	[8]	If needed, further customize the list of variable and re-run the commands, until you obtain a satisfactory model.


define urbanvars ()
 	persroom
 	hc3@11 hc3@12 hc3@21 hc3@22 hc3@31 hc3@32 hc3@33 hc3@34 hc3@35
 	hc4@11 hc4@12 hc4@13 hc4@21 hc4@22 hc4@23 hc4@24 hc4@31 hc4@32 
		hc4@33 hc4@34 hc4@35 hc4@36
 	hc5@11 hc5@12 hc5@13 hc5@21 hc5@22 hc5@23 hc5@24 hc5@25 hc5@26 +
		hc5@31 hc5@32 hc5@33 hc5@34 hc5@35 hc5@36
  	hc6@01 hc6@02 hc6@03 hc6@04 hc6@05 hc6@06 hc6@07 hc6@08 hc6@09 
		hc6@10 hc6@11 hc6@95
  	hc8a@1 hc8b@1 hc8c@1 hc8d@1 hc8e@1 hc8f@1
  	hc9a@1 hc9b@1 hc9c@1 hc9d@1 hc9e@1 hc9f@1 hc9g@1 hc9h@1
 	hc10@1 hc10@2 hc10@6
	hc12r@0 hc12r@1 hc12r@2 hc12r@3
 	hc14a@0 hc14a@1 hc14a@2 hc14a@3
  	hc14b@0 hc14b@1 hc14b@2 hc14b@3
  	hc14c@0 hc14c@1 hc14c@2 hc14c@3 
  	hc14d@0 hc14d@1 hc14d@2 hc14d@3 
  	hc14e@0 hc14e@1 hc14e@2 hc14e@3 
  	hc14f@0 hc14f@1 hc14f@2 hc14f@3 
	hc15@1
  	ws1@11 ws1@12 ws1@13 ws1@14 ws1@21 ws1@31 ws1@32 
		ws1@41 ws1@42 ws1@51 ws1@61 ws1@71 ws1@81 ws1@91
  	watloc@1 watloc@2 watloc@3 watloc@4
	latshare lathh1 lathh2
  	ws8@11 ws8@12 ws8@13 ws8@14 ws8@15 ws8@21 ws8@22 ws8@23 
		ws8@31 ws8@41 ws8@51 ws8@95
 	hw2@1 soap@1
	servant abroad
!enddefine.


*	It is necessary to first delete the urb1 variable as new runs will not replace the values
	Before the first run of "factor", this will generate an error message, since the program will 
	not be able to find the urb1 variable to delete - ignore this message.
delete variables urb1.


factor
	/variables urbanvars
	/missing meansub
	/analysis urbanvars
	/print univariate initial extraction fscore
	/criteria factors(1) iterate(25)
	/extraction pc
	/rotation norotate 	 
	/save reg(all urb)
	/method=correlation.

* 	Create the SPSS output.
* 	Make sure to change X with number corresponding to each iterative running of the command. 
*	First run output should be marked as 1, second as 2, etc., until model is found to be satisfactory.
output save outfile = "wealth3 syntax output run number X.spv".

* 	After reviewing the model make sure to close the output.
output close.
