* =================================================================
RUN REGRESSIONS
==================================================================

use all.

*	Runs regressions to establish relationships between the two sets of scores (urban and rural) and the initial (common) wealth factors.
variable labels ini1 	"Initial wealth score".
variable labels urb1 	"Urban wealth score".
variable labels rur1 	"Rural wealth score".

*	Basic statistics for the three wealth scores, to check denominators, totals, means etc.
descriptives variables = ini1 urb1 rur1.

* 	Create the SPSS output.
output save outfile = "wealth6 syntax output run number X.spv".

use all.
string ROWTYPE_ (A8).
compute ROWTYPE_ = 'EST'.


* =================================================================
*	Calculate regressions of urban wealth scores with the initial (common) wealth scores, add constants and coefficients to dataset.
use all.
filter by urban.
execute.

dataset declare urbcorv.
regression
  /missing listwise
  /statistics coeff outs r anova
  /criteria=pin(.05) pout(.10)
  /noorigin
  /dependent ini1
  /method=enter urb1
  /outfile=corv(urbcorv).
dataset activate urbcorv.
select if (ROWTYPE_ = 'EST').
execute.
delete variables DEPVAR_ VARNAME_.
rename variables CONST_=urbconst urb1=urbcoeff.

dataset activate assets.
rename variables urb1=urbscore.
match files
  /file = *
  /table = urbcorv
  /by ROWTYPE_.
execute.


* =================================================================
*	Calculate regressions of rural wealth scores with the initial (common) wealth scores, add constants and coefficients to dataset.
use all.
filter by rural.

dataset declare rurcorv.
regression
  /missing listwise
  /statistics coeff outs r anova
  /criteria=pin(.05) pout(.10)
  /noorigin
  /dependent ini1
  /method=enter rur1
  /outfile=corv(rurcorv).
dataset activate rurcorv.
select if (ROWTYPE_ = 'EST').
execute.
delete variables DEPVAR_ VARNAME_.
rename variables CONST_=rurconst rur1=rurcoeff.

dataset activate assets.
rename variables rur1=rurscore.
match files
  /file = *
  /table = rurcorv
  /by ROWTYPE_.
execute.



dataset close urbcorv.
dataset close rurcorv.
dataset activate assets.
use all.
delete variables rowtype_.


* 	Close the output.
output close.



