* =================================================================
CREATE QUINTILES, REVIEW AND COMPARE RESULTS
==================================================================

*	Quintiles are created for the total sample using combined wealth scores. For the urban and rural samples, 
		quintiles are created by using their respective wealth scores
	These will later be saved onto the data sets (wealth9.sps)
	To review and compare results, quintiles are also created from the initial (common) wealth scores.


*================================================================================================.
*	Create initial (common) quintiles.
use all.
execute.
rank variables=iniscore (a) /ntiles (5) /print=yes /ties=mean.

* 	Create urban quintiles.
use all.
filter by urban.
execute.
rank variables=urbscore (a) /ntiles (5) /print=yes /ties=mean.

*	Create rural quintiles.
use all.
filter by rural.
execute.
rank variables=rurscore (a) /ntiles (5) /print=yes /ties=mean.

*	Create combined quintiles.
use all.
execute.
rank variables=comscore (a) /ntiles (5) /print=yes /ties=mean.


formats urbscore rurscore comscore iniscore (f9.5).
variable labels ncomscor 	"Wealth index quintile".
variable labels nurbscor	"Urban wealth index quintile".
variable labels nrurscor	"Rural wealth index quintile".
variable labels niniscor		"Initial (common) wealth index quintile".
value labels nurbscor nrurscor ncomscor niniscor
	1 'Poorest'
	2 'Second'
	3 'Middle'
	4 'Fourth'
	5 'Richest'.
formats nurbscor nrurscor ncomscor niniscor (f1.0).


*=============================================================================================================================.
*	Comparison of the results - Does the combined approach classify more rural households into higher quintiles.

* 	Distribution of urban, rural and national household populations to wealth quintiles by initial (common) and combined approaches.
ctables	/table urban [c] + rural [c] + national [c] by niniscor [c]  [rowpct 'Percent' f4.1 count 'Count' f5.0]
	/titles title = surveyname 
		"Distribution of urban and rural household populations to initial (common) wealth quintiles".
ctables	/table urban [c] + rural [c] + national [c] by ncomscor [c]  [rowpct 'Percent' f4.1 count 'Count' f5.0]
	/titles title = surveyname 
		"Distribution of urban and rural household populations to combined wealth quintiles".


*==================================================================================================================================.
*	Comparison of the results - Amount of change in the classification of household populations from initial (common) to combined wealth quintiles.
*	National.
ctables	/table niniscor [c] by ncomscor [c]
	/categories variables=niniscor ncomscor total=yes
	/titles title=surveyname
		"Distribution of household populations to quintiles according to initial (common) and combined wealth index approaches".
crosstabs 	/tables = niniscor by ncomscor
	/statistics = kappa
	/format = notables.
*	Urban.
use all.
filter by urban.
execute.
ctables	/table niniscor [c] by ncomscor [c]
	/categories variables=niniscor ncomscor total=yes
	/titles title= surveyname
		"Distribution of urban household populations to quintiles according to initial (common) and combined wealth index approaches".
crosstabs 	/tables = niniscor by ncomscor
	/statistics = kappa
	/format = notables.
*	Rural.
use all.
filter by rural.
execute.
ctables	/table niniscor [c] by ncomscor [c]
	/categories variables=niniscor ncomscor total=yes
	/titles title= surveyname
		"Distribution of rural household populations to quintiles according to initial (common) and combined wealth index approaches".
crosstabs 	/tables = niniscor by ncomscor
	/statistics = kappa
	/format = notables.
use all.
execute.


*==================================================================================================================================.
*	Comparison of the results - Average wealth scores.
ctables	/table national [c] + hh6 [c] + HH7 [c]
	by (iniscore + urbscore + rurscore + comscore) [s] [mean, 'Average scores',f7.5]
	/titles title= surveyname
		"Average wealth scores for initial (common), urban, rural and combined indexes - urban-rural areas and regions".

ctables 	/vlabels variables = comscore display = none
	/table hh7 [c] > comscore [s] [mean 'Average wealth score' f7.5 validn 'Count' f5.0]
	by hh6 [c]
	/categories variables = hh6 hh7 total = yes
	/titles title= surveyname
		"Average combined wealth scores for urban and rural areas within regions".


weight off.
weight by hhweight.

*================================================================================================.
*	Quality of indexes - repetition of factor scores, combined index.
sort cases comscore (A).
compute comscoreheap = 100.
compute comscoreprev = lag (comscore).
create comscorenext = lead (comscore,1).
if (comscore = comscoreprev or comscore = comscorenext) comscoreheap=0.
if (hh9 ne 1 or sysmis(comscore)) comscoreheap=999.
missing values comscoreheap (999).
execute.

*	Quality of indexes - repetition of factor scores, initial (common) index.
sort cases iniscore (A).
compute iniscoreheap = 100.
compute iniscoreprev = lag (iniscore).
create iniscorenext = lead (iniscore,1).
if (iniscore = iniscoreprev or iniscore = iniscorenext) iniscoreheap=0.
if (hh9 ne 1 or sysmis(iniscore)) iniscoreheap=999.
missing values iniscoreheap (999).
execute.

*	Quality of indexes - repetition of factor score, urban index.
sort cases urbscore (A).
compute urbscoreheap = 100.
compute urbscoreprev = lag (urbscore).
create urbscorenext = lead (urbscore,1).
if (urbscore = urbscoreprev or urbscore = urbscorenext) urbscoreheap=0.
if (hh9 ne 1 or hh6 ne 1) urbscoreheap=999.
missing values urbscoreheap (999).
execute.

*	Quality of indexes - repetition of factor score, rural index.
sort cases rurscore (A).
compute rurscoreheap = 100.
compute rurscoreprev = lag (rurscore).
create rurscorenext = lead (rurscore,1).
if (rurscore = rurscoreprev or rurscore = rurscorenext) rurscoreheap=0.
if (hh9 ne 1 or hh6 ne 2) rurscoreheap=999.
missing values rurscoreheap (999).
execute.

variable labels
comscoreheap	"Combined factor scores"
iniscoreheap	"initial (common) factor scores"
urbscoreheap	"Urban factor scores"
rurscoreheap	"Rural factor scores".

ctables 	/table (comscoreheap + iniscoreheap + urbscoreheap + rurscoreheap)  [s] [mean 'Percentage' f6.2 validn 'Count' f5.0]
	/titles title= surveyname
		"Percentage of households with unique factor scores".


*================================================================================================.
* Run summary statistics for all recoded variables used for wealth index analysis, for initial (common) and combined quintiles.
cwealthmeans 	((persroom)).
cwealthmeans 	((hc3@11 + hc3@12 + hc3@21 + hc3@22 + hc3@31 + hc3@32 + hc3@33 + hc3@34 + hc3@35)).
cwealthmeans 	((hc4@11 + hc4@12 + hc4@13 + hc4@21 + hc4@22 + hc4@23 + hc4@24 + hc4@31 + hc4@32 + 
		hc4@33 + hc4@34 + hc4@35 + hc4@36)).
cwealthmeans 	((hc5@11 + hc5@12 + hc5@13 + hc5@21 + hc5@22 + hc5@23 + hc5@24 + hc5@25 + hc5@26 +
		hc5@31 + hc5@32 + hc5@33 + hc5@34 + hc5@35 + hc5@36)).
cwealthmeans  	((hc6@01 + hc6@02 + hc6@03 + hc6@04 + hc6@05 + hc6@06 + hc6@07 + hc6@08 + hc6@09 + 
		hc6@10 + hc6@11 + hc6@95)).
cwealthmeans  	((hc8a@1 + hc8b@1 + hc8c@1 + hc8d@1 + hc8e@1 + hc8f@1)).
cwealthmeans  	((hc9a@1 + hc9b@1 + hc9c@1 + hc9d@1 + hc9e@1 + hc9f@1 + hc9g@1 + hc9h@1)).
cwealthmeans 	((hc10@1 + hc10@2 + hc10@6)).
cwealthmeans	((hc12r@0 + hc12r@1 + hc12r@2 + hc12r@3)).
cwealthmeans 	((hc14a@0 + hc14a@1 + hc14a@2 + hc14a@3)).
cwealthmeans  	((hc14b@0 + hc14b@1 + hc14b@2 + hc14b@3)).
cwealthmeans  	((hc14c@0 + hc14c@1 + hc14c@2 + hc14c@3)). 
cwealthmeans  	((hc14d@0 + hc14d@1 + hc14d@2 + hc14d@3)). 
cwealthmeans  	((hc14e@0 + hc14e@1 + hc14e@2 + hc14e@3)). 
cwealthmeans  	((hc14f@0 + hc14f@1 + hc14f@2 + hc14f@3)). 
cwealthmeans	((hc15@1)).
cwealthmeans  	((ws1@11 + ws1@12 + ws1@13 + ws1@14 + ws1@21 + ws1@31 + ws1@32 + 
		ws1@41 + ws1@42 + ws1@51 + ws1@61 + ws1@71 + ws1@81 + ws1@91)).
cwealthmeans  	((watloc@1 + watloc@2 + watloc@3 + watloc@4)).
cwealthmeans	((latshare + lathh1 + lathh2)).
cwealthmeans  	((ws8@11 + ws8@12 + ws8@13 + ws8@14 + ws8@15 + ws8@21 + ws8@22 + ws8@23 + 
		ws8@31 + ws8@41 + ws8@51 + ws8@95)).
cwealthmeans 	((hw2@1 + soap@1)).
cwealthmeans	((servant + abroad)).

* 	Create the SPSS output.
output save outfile = "wealth8 syntax output run number X.spv".

* 	After reviewing the model make sure to close the output.
output close.